using System;
using System.Data;
using System.Linq;

namespace CSVParser
{
    public class CsvReader
    {
        /// <summary>
        /// Parses the specified text as csv into a datatable.
        /// </summary>
        /// <param name="text">CSV text.</param>
        /// <returns>DataTable representing csv file.</returns>
        public static DataTable Parse(string text)
        {
            //Let's use a datatable! 
            var table = new DataTable();
            if ( string.IsNullOrEmpty(text) )
            {
                //nothing to parse
                return table;
            }
            var lines = text.Split(new[] { '\n', '\r' }, StringSplitOptions.RemoveEmptyEntries);
            var headerLine = lines[0];
            BuildColumnHeaders(headerLine, table);
            var dataLines = lines.Skip(1);
            foreach ( var line in dataLines )
            {
                AddDataRow(line, table);
            }
            return table;
        }

        private static void AddDataRow(string line, DataTable table)
        {
            var row = table.NewRow();
            var data = CsvTokenizer.TokenizeLine(line);
            if ( data.Count != table.Columns.Count )
            {
                throw new InvalidOperationException("Data Row does not have same field count as header row.");
            }
            for ( int i = 0; i < data.Count; i++ )
            {
                row[i] = data[i];
            }
            table.Rows.Add(row);
        }

        private static void BuildColumnHeaders(string headerLine, DataTable table)
        {
            var headers = CsvTokenizer.TokenizeLine(headerLine);
            foreach ( var header in headers )
            {
                table.Columns.Add(header);
            }
        }

        
    }

}