using System;
using NUnit.Framework;
using System.Linq;

namespace CSVParser
{
    [TestFixture]
    public class CsvTokenizerTests
    {
        [Test]
        public void TokenizesEmptyLine()
        {
            var line = CsvTokenizer.TokenizeLine("");
            Assert.NotNull(line);
            Assert.That(line.Count, Is.EqualTo(1));
            Assert.That(line[0], Is.EqualTo(""));
        }

        [Test]
        public void TokenizesSimpleFields()
        {
            var line = CsvTokenizer.TokenizeLine("a,b,c");
            Assert.That(line.Count, Is.EqualTo(3));
            Assert.That(line[1], Is.EqualTo("b"));
        }

        [Test]
        public void PreservesWhiteSpace()
        {
            var line = CsvTokenizer.TokenizeLine("a, b  ,c");
            Assert.That(line.Count, Is.EqualTo(3));
            Assert.That(line[1], Is.EqualTo(" b  "));
        }

        [Test]
        public void QuotedValues()
        {
            var line = CsvTokenizer.TokenizeLine("a,\"b\",\"c\"");
            Assert.That(line.Count, Is.EqualTo(3));
            Assert.That(line[1], Is.EqualTo("b"));
        }

        [Test]
        public void CommasInQuotes()
        {
            var line = CsvTokenizer.TokenizeLine("a,\"b,d\",c");
            Assert.That(line[1], Is.EqualTo("b,d"));
        }

        [Test]
        public void QuotesInQuotes()
        {
            var line = CsvTokenizer.TokenizeLine("a,\"b,\"\"d\",c");
            Assert.That(line[1], Is.EqualTo("b,\"d"));
        }

        [Test]
        public void InvalidQuoteStructures()
        {
            Assert.Throws<InvalidOperationException>(() => CsvTokenizer.TokenizeLine("\"foo\" bar"));
            Assert.Throws<InvalidOperationException>(() => CsvTokenizer.TokenizeLine("foo \"bar\""));
            Assert.Throws<InvalidOperationException>(() => CsvTokenizer.TokenizeLine("\"unclosed"));
        }

        [Test]
        public void EmptyTokens()
        {
            var line = CsvTokenizer.TokenizeLine(",,,,");
            Assert.That(line.Count, Is.EqualTo(5));
            Assert.That(line.All(x => x == string.Empty));
        }
    }
}