using System;
using System.Data;
using System.IO;
using NUnit.Framework;

namespace CSVParser
{
    [TestFixture]
    public class CsvWriterTests
    {
        
        [Test]
        public void EmptyDataTable()
        {
            var stream = new StringWriter();
            CsvWriter.Write(new DataTable(), stream);
            Assert.That(stream.ToString(), Is.EqualTo(Environment.NewLine));
        }

        [Test]
        public void PrintsHeaders()
        {
            DataTable table = new DataTable();
            table.Columns.Add("Foo");
            table.Columns.Add("Bar");
            var stream = new StringWriter();
            CsvWriter.Write(table, stream);
            Assert.That(stream.ToString(), Is.EqualTo("[Foo] [Bar]" + Environment.NewLine));
        }

        [Test]
        public void FullTable()
        {
            DataTable table = new DataTable();
            table.Columns.Add("Foo");
            table.Columns.Add("Bar");
            table.Rows.Add("a", "\"b\"");
            table.Rows.Add("1", "2");
            var stream = new StringWriter();
            CsvWriter.Write(table, stream);
            var expected = string.Format("[Foo] [Bar]{0}[a] [\"b\"]{0}[1] [2]{0}", Environment.NewLine);
            Assert.That(stream.ToString(), Is.EqualTo(expected));
        }
    }
}